..
  SPDX-FileCopyrightText: 2024 Free Software Foundation Europe e.V. <https://fsfe.org>

  SPDX-License-Identifier: CC-BY-SA-4.0

reuse-convert-dep5
==================

Synopsis
--------

**reuse convert-dep5** [*options*]

Description
-----------

:program:`reuse-convert-dep5` converts the ``.reuse/dep5`` file into a
functionally equivalent ``REUSE.toml`` file in the root of the project. The
``.reuse/dep5`` file is subsequently deleted.

Options
-------

.. option:: -h, --help

  Display help and exit.
